@@ -211,6 +211,7 @@ def up(
 
         try:
             if restart:
+                s.stop()
                 s.remove()
 
             s.start()
@@ -275,6 +276,8 @@ def down(
 
             if prune:
                 s.remove(prune=True)
+            else:
+                s.remove()
 
             s.echo()
         except Exception as e:
